@@ -81,7 +81,7 @@ sub configure_libmodperl {
             my $lib = "$Config{installbin}\\$Config{libperl}";
             $lib =~ s/lib$/dll/;
             $cfg = 'LoadFile ' . qq("$lib"\n) if -e $lib;
-	}
+        }
         # add the module we found to the cached modules list
         # otherwise have_module('mod_perl') doesn't work unless
         # we have a LoadModule in our base config
@@ -105,11 +105,20 @@ sub configure_inc {
     my $top = $self->{vars}->{top_dir};
 
     my $inc = $self->{inc};
-    my @trys = (catdir($top, qw(blib lib)),
-                catdir($top, qw(blib arch)));
 
-    for (@trys) {
-        push @$inc, $_ if -d $_;
+    my $found;
+    for (catdir($top, qw(blib lib)), catdir($top, qw(blib arch))) {
+        if (-d $_) {
+	    push @$inc, $_;
+	    $found=1;
+	}
+    }
+
+    # try ../blib as well for Apache::Reload & Co
+    unless ($found) {
+        for (catdir($top, qw(.. blib lib)), catdir($top, qw(.. blib arch))) {
+	    push @$inc, $_ if -d $_;
+	}
     }
 
     # spec: If PERL5LIB is defined, PERLLIB is not used.
@@ -148,9 +157,10 @@ EOF
 # propogate PerlPassEnv settings to the server
 sub configure_env {
     my $self = shift;
-    $self->preamble(IfModule => 'mod_perl.c', 
+    $self->preamble(IfModule => 'mod_perl.c',
                     [ qw(PerlPassEnv APACHE_TEST_TRACE_LEVEL
-                         PerlPassEnv HARNESS_PERL_SWITCHES)
+                         PerlPassEnv HARNESS_PERL_SWITCHES
+                         PerlPassEnv APACHE_TEST_NO_STICKY_PREFERENCES)
                     ]);
 }
 
